# vim: set sw=4 ts=4 et:
#
# spec file for package libgig
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover  7
Name:           libgig
Version:        4.0.0
Release:        5.1
Summary:        Library for loading Gigasampler files and DLS Level 1/2 files
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Utilities
Url:            http://linuxsampler.org/
Source0:        http://download.linuxsampler.org/packages/libgig-%{version}.tar.bz2
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  e2fsprogs-devel
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(sndfile) >= 1.0.2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
C++ library for loading Gigasampler files and DLS Level 1/2 files.

%package -n libgig%{sover}
Summary:        Library for loading Gigasampler files and DLS Level 1/2 files
Group:          System/Libraries

%description -n libgig%{sover}
C++ library for loading Gigasampler files and DLS Level 1/2 files.

%package -n libgig-devel
Summary:        C++ library for loading Gigasampler files and DLS Level 1/2 files
Group:          Development/Languages/C and C++
Requires:       libgig%{sover} = %{version}

%description -n libgig-devel
C++ library for loading Gigasampler files and DLS Level 1/2 files.

%package -n libgig-tools
Summary:        Example applications for libgig
Group:          Productivity/Multimedia/Sound/Utilities
Requires:       libgig%{sover} = %{version}
Provides:       libgig6-tools = %{version}
Obsoletes:      libgig6-tools < %{version}

%description -n libgig-tools
Some example applications for the libgig package.

* gigdump: demo app that prints out the content of a .gig file
* gigextract: extracts samples from a .gig file
* dlsdump: demo app that prints out the content of a DLS file
* rifftree: tool that prints out the RIFF tree of an arbitrary RIFF file

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d/
  echo "%{_libdir}/libgig" > "%{buildroot}%{_sysconfdir}/ld.so.conf.d/libgig%{sover}.conf"

%post   -n libgig%{sover} -p /sbin/ldconfig
%postun -n libgig%{sover} -p /sbin/ldconfig

%files -n libgig%{sover}
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README TODO
%dir %{_libdir}/libgig/
%{_libdir}/libgig/libgig.so.%{sover}
%{_libdir}/libgig/libgig.so.%{sover}.*
%config %{_sysconfdir}/ld.so.conf.d/libgig%{sover}.conf

%files -n libgig-devel
%defattr(-,root,root)
%dir %{_libdir}/libgig/
%dir %{_includedir}/libgig/
%{_libdir}/libgig/libgig.so
%{_includedir}/libgig/DLS.h
%{_includedir}/libgig/RIFF.h
%{_includedir}/libgig/SF.h
%{_includedir}/libgig/gig.h
%{_includedir}/libgig/Akai.h
%{_includedir}/libgig/Korg.h
%{_libdir}/libgig/libakai.so
%{_libdir}/libgig/libakai.so.0
%{_libdir}/libgig/libakai.so.0.0.0
%{_libdir}/pkgconfig/akai.pc
%{_libdir}/pkgconfig/gig.pc

%files -n libgig-tools
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README TODO
%{_bindir}/akaidump
%{_bindir}/akaiextract
%{_bindir}/dlsdump
%{_bindir}/gig2mono
%{_bindir}/gig2stereo
%{_bindir}/gigdump
%{_bindir}/gigextract
%{_bindir}/gigmerge
%{_bindir}/korg2gig
%{_bindir}/korgdump
%{_bindir}/rifftree
%{_bindir}/sf2dump
%{_bindir}/sf2extract
%{_mandir}/man1/*.1*

%changelog
* Sun Feb 12 2017 olaf@aepfle.de
- Update to version 4.0.0
* Mon Sep  5 2016 edogawa@aon.at
- removed version strings from date/email lines in libgig.changes
- ran spec-cleaner on libgig.spec
* Fri Sep  2 2016 edogawa@aon.at
- fixed crippled mail addresses in libgig.changes
* Thu Aug 11 2016 jengelh@inai.de
- Correction of RPM groups, abolish old macros and %%clean section.
  Rename soname macro to sover because there was no name in it.
* Fri Feb 19 2016 edogawa@aon.at
- split out changelog into separate .changes file
* Wed Dec 17 2014 giordanoboschetti@gmail.com
- update to svn trunk rev 2680
* Mon Apr 16 2012 pascal.bleser@opensuse.org
- update to svn trunk rev 2342
* Sat Feb 27 2010 toni@links2linux.de
- update to 3.3.0
* Fri Dec  7 2007 toni@links2linux.de
- update to 3.2.1
* Mon Oct 15 2007 toni@links2linux.de
- update to 3.2.0
* Sun Oct 14 2007 toni@links2linux.de
- update to 3.2.0-cvs20071014
* Sun Oct  7 2007 toni@links2linux.de
- update to 3.1.1-cvs20071006
* Tue Oct  2 2007 toni@links2linux.de
- update to 3.1.1-cvs20071001
* Tue Sep 11 2007 toni@links2linux.de
- update to 3.1.1-cvs20070910
* Fri Aug  3 2007 toni@links2linux.de
- update to 3.1.1-cvs20070802
* Fri Jul  6 2007 toni@links2linux.de
- update to 3.1.1-cvs20070622
* Sun Jun  3 2007 toni@links2linux.de
- update to 3.1.1-cvs20070601
- changed package-layout according new Shared Library Packaging Policy
* Sat May 26 2007 toni@links2linux.de
- update to 3.1.1-cvs20070525
* Sun May 13 2007 toni@links2linux.de
- update to 3.1.1-cvs20070513
* Mon Apr 16 2007 toni@links2linux.de
- update to 3.1.1-cvs20070413
* Sat Mar 24 2007 toni@links2linux.de
- update to 3.1.1-cvs20070324
* Wed Nov 29 2006 toni@links2linux.de
- update to 3.1.0-final
* Fri Nov 24 2006 toni@links2linux.de
- update to 3.1.0-cvs20061124
* Mon Oct 30 2006 toni@links2linux.de
- update to 3.0.0-cvs20061030
* Thu Oct 26 2006 toni@links2linux.de
- update to 3.0.0-cvs20061026
* Fri Oct 20 2006 toni@links2linux.de
- update to 3.0.0-cvs20061019
* Mon Sep 18 2006 toni@links2linux.de
- build for packman
* Sat Sep  2 2006 oc2pus@arcor.de 
- update to 3.0.0-cvs20060902
* Sun Aug 20 2006 oc2pus@arcor.de 
- update to 3.0.0-cvs20060820
* Fri Aug 11 2006 oc2pus@arcor.de 
- update to 3.0.0-cvs20060811
* Sat Jul 22 2006 oc2pus@arcor.de 
- update to 3.0.0-cvs20060722
* Thu Jun  1 2006 oc2pus@arcor.de 
- update to 3.0.0-cvs20060601
* Sun May 14 2006 oc2pus@arcor.de 
- update to 3.0.0-cvs20060514
* Sat May  6 2006 oc2pus@arcor.de 
- update to 3.0.0-cvs20060506
* Sun Apr 30 2006 oc2pus@arcor.de 
- update to 3.0.0
* Fri Mar  3 2006 oc2pus@arcor.de 
- update to cvs20060303
* Mon Dec 26 2005 oc2pus@arcor.de 
- update to cvs20051226
* Thu Dec 22 2005 oc2pus@arcor.de 
- update to cvs20051222
* Fri Nov 25 2005 oc2pus@arcor.de 
- update to cvs20051125
* Tue Nov 22 2005 oc2pus@arcor.de 
- update to cvs20051122
* Thu Nov 17 2005 oc2pus@arcor.de 
- update to cvs20051117
* Sat Nov 12 2005 oc2pus@arcor.de 
- update to cvs20051112
* Fri Nov  4 2005 oc2pus@arcor.de 
- update to cvs20051104
* Mon Sep 26 2005 oc2pus@arcor.de 
- update to cvs20050917
* Sat Sep 17 2005 oc2pus@arcor.de 
- update to cvs20050917
- changes in spec-file for build on x86_64
* Wed Aug 17 2005 oc2pus@arcor.de 
- update to cvs20050816
* Tue Aug  2 2005 oc2pus@arcor.de 
- update to cvs20050726
* Mon Jul 18 2005 oc2pus@arcor.de 
- update to cvs20050718
* Sun Jun 19 2005 oc2pus@arcor.de 
- update to cvs20050619
* Mon Jun 13 2005 oc2pus@arcor.de 
- update to cvs20050613
* Tue Jun  7 2005 oc2pus@arcor.de 
- update to cvs20050607
* Mon Jun  6 2005 oc2pus@arcor.de 
- update to cvs20050606
* Wed May 18 2005 oc2pus@arcor.de 
- update to cvs20050518
* Mon May  9 2005 oc2pus@arcor.de 
- update to cvs20050509
- removed Patch
* Sun May  8 2005 oc2pus@arcor.de 
- update to cvs20050508
- included Patch for VERSION/PACKAGE
* Thu May  5 2005 oc2pus@arcor.de 
- update to cvs20050505
* Tue May  3 2005 oc2pus@arcor.de 
- update to cvs20050503
- added audiofile to Requires/BuildRequires
* Mon Mar  7 2005 oc2pus@arcor.de 
- build for SuSE
- little modifications using RPM-macros
* Wed Nov 24 2004 rncbc@users.sourceforge.net
- prepared for 1.0.0
* Sat Jul 10 2004 cuse@users.sourceforge.net
- renamed 'libgig.pc' to 'gig.pc' as well as the pkg-config lib name
* Fri Jul  2 2004 rncbc@users.sourceforge.net
- Created and corrected initial libgig.spec
